#include "combat_ui.hpp"
#include "constants.hpp"
#include "color.hpp"
#include "events.hpp"

namespace gui {
  using namespace guecs;

  CombatUI::CombatUI(GameLevel level) :
      $level(level)
  {
    $gui.position(RAY_VIEW_X, RAY_VIEW_HEIGHT, RAY_VIEW_WIDTH, SCREEN_HEIGHT - RAY_VIEW_HEIGHT);
    $gui.layout(
        "[*%(100,150)button_attack1 | *%(100,150)button_attack2 | *%(100,150)button_attack3 | *%(100,150)button_heal]"
        "[ >.%(100,50)label_hp | *%.(198,50)bar_hp | _ ]");
  }

  void CombatUI::render() {
    auto& world = $gui.world();

    world.set_the<Background>({$gui.$parser});

    for(auto& [name, cell] : $gui.cells()) {
      if(name.starts_with("button_")) {
        auto button = $gui.entity(name);
        world.set<lel::Cell>(button, cell);
        world.set<Rectangle>(button, {});
        world.set<Clickable>(button,
            guecs::make_action(*$level.world, Events::GUI::ATTACK));
        world.set<Label>(button, {"Attack"});
      } else if(name.starts_with("bar_")) {
        $meter = $gui.entity(name);
        world.set<lel::Cell>($meter, cell);
        world.set<Rectangle>($meter, {});
        world.set<Meter>($meter, {});
      } else {
        // ignored, it's just space
        $gui.entity(name);
      }
    }

    $gui.init();
  }

  void CombatUI::draw(sf::RenderWindow& window) {
    $gui.render(window);
  }

  void CombatUI::set_damage(float percent) {
    fmt::println("combat ui sets damage: {}", percent);
    auto& meter = $gui.world().get<Meter>($meter);
    meter.percent = percent;
  }
}
